pub struct ScoreboardEvents {
pub admit: bool,
pub admit_job: b32,
pub admit_cluster: b2,
pub frame_start: bool,
pub frame_start_job: b32,
pub frame_start_cluster: b2,
pub frame_finish: bool,
pub frame_finish_job: b32,
pub error: bool,
pub error_job: b32,
pub error_cluster: b2,
}Expand description
Independent ownership transitions that may coincide for different jobs.
Fields
admit: boolAllocate one newly admitted job.
admit_job: b32Job named by admit.
admit_cluster: b2Cluster reported by the accepted signer admission.
frame_start: boolMove one active job to streaming on accepted beat zero.
frame_start_job: b32Job named by frame_start.
frame_start_cluster: b2Cluster carried by frame beat zero.
frame_finish: boolRemove one streaming job after canonical beat 34 reaches BRAM.
frame_finish_job: b32Job named by frame_finish.
error: boolRemove one active job on an explicit signer error completion.
error_job: b32Job named by error.
error_cluster: b2Cluster carried by the signer error completion.